betty.classtools module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.classtools module

Provide class utilities.

betty.classtools.repr_instance(instance: object, **attributes: Any) → str

  Build a representation of an instance.

  Parameters:

    - instance (`object`)

    - attributes (`typing.Any`)

  Return type:

    `str`